@@ -1,7 +1,7 @@
 // qsamplerDevice.cpp
 //
 /****************************************************************************
-   Copyright (C) 2004-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2004-2012, rncbc aka Rui Nuno Capela. All rights reserved.
    Copyright (C) 2007, 2008 Christian Schoenebeck
 
    This program is free software; you can redistribute it and/or
@@ -916,11 +916,11 @@ DeviceItem::DeviceItem ( QTreeWidget* pTreeWidget,
 {
 	switch(m_device.deviceType()) {
 	case Device::Audio:
-		setIcon(0, QPixmap(":/icons/audio1.png"));
+		setIcon(0, QPixmap(":/images/audio1.png"));
 		setText(0, QObject::tr("Audio Devices"));
 		break;
 	case Device::Midi:
-		setIcon(0, QPixmap(":/icons/midi1.png"));
+		setIcon(0, QPixmap(":/images/midi1.png"));
 		setText(0, QObject::tr("MIDI Devices"));
 		break;
 	case Device::None:
@@ -939,10 +939,10 @@ DeviceItem::DeviceItem ( QTreeWidgetItem* pItem,
 {
 	switch(m_device.deviceType()) {
 	case Device::Audio:
-		setIcon(0, QPixmap(":/icons/audio2.png"));
+		setIcon(0, QPixmap(":/images/audio2.png"));
 		break;
 	case Device::Midi:
-		setIcon(0, QPixmap(":/icons/midi2.png"));
+		setIcon(0, QPixmap(":/images/midi2.png"));
 		break;
 	case Device::None:
 		break;
@@ -1018,7 +1018,12 @@ void AbstractDeviceParamModel::refresh (
 	m_pParams   = pParams;
 	m_bEditable = bEditable;
 	// inform the outer world (QTableView) that our data changed
+#if QT_VERSION < 0x050000
 	QAbstractTableModel::reset();
+#else
+	QAbstractTableModel::beginResetModel();
+	QAbstractTableModel::endResetModel();
+#endif
 }
 
 
@@ -1026,7 +1031,12 @@ void AbstractDeviceParamModel::clear (void)
 {
 	m_pParams = NULL;
 	// inform the outer world (QTableView) that our data changed
+#if QT_VERSION < 0x050000
 	QAbstractTableModel::reset();
+#else
+	QAbstractTableModel::beginResetModel();
+	QAbstractTableModel::endResetModel();
+#endif
 }
 
 
@@ -1194,7 +1204,7 @@ QWidget* DeviceParamDelegate::createEditor ( QWidget *pParent,
 				);
 				pSpinBox->setMaximum(
 					(!r.param.range_max.isEmpty()) ?
-						r.param.range_max.toInt() : (1 << 16) // or better a nigher default max value ?
+						r.param.range_max.toInt() : (1 << 24) // or better a higher default max value ?
 				);
 				pSpinBox->setValue(val.toInt());
 				return pSpinBox;
