@@ -1,7 +1,7 @@
 // qsamplerDeviceForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2004-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2004-2015, rncbc aka Rui Nuno Capela. All rights reserved.
    Copyright (C) 2007, 2008 Christian Schoenebeck
 
    This program is free software; you can redistribute it and/or
@@ -28,6 +28,8 @@
 #include <QHeaderView>
 #include <QMessageBox>
 
+#include <QCheckBox>
+
 
 namespace QSampler {
 
@@ -60,12 +62,20 @@ DeviceForm::DeviceForm ( QWidget *pParent, Qt::WindowFlags wflags )
 
 	m_ui.DeviceParamTable->setModel(&m_deviceParamModel);
 	m_ui.DeviceParamTable->setItemDelegate(&m_deviceParamDelegate);
+#if QT_VERSION >= 0x050000
+	m_ui.DeviceParamTable->horizontalHeader()->setSectionResizeMode(2, QHeaderView::Stretch);
+#else
 	m_ui.DeviceParamTable->horizontalHeader()->setResizeMode(2, QHeaderView::Stretch);
+#endif
 	m_ui.DeviceParamTable->verticalHeader()->hide();
 
 	m_ui.DevicePortParamTable->setModel(&m_devicePortParamModel);
 	m_ui.DevicePortParamTable->setItemDelegate(&m_devicePortParamDelegate);
+#if QT_VERSION >= 0x050000
+	m_ui.DevicePortParamTable->horizontalHeader()->setSectionResizeMode(2, QHeaderView::Stretch);
+#else
 	m_ui.DevicePortParamTable->horizontalHeader()->setResizeMode(2, QHeaderView::Stretch);
+#endif
 	m_ui.DevicePortParamTable->verticalHeader()->hide();
 
 	// Initial contents.
@@ -273,15 +283,31 @@ void DeviceForm::deleteDevice (void)
 	// Prompt user if this is for real...
 	Options *pOptions = pMainForm->options();
 	if (pOptions && pOptions->bConfirmRemove) {
-		if (QMessageBox::warning(this,
-			QSAMPLER_TITLE ": " + tr("Warning"),
-			tr("About to delete device:\n\n"
+		const QString& sTitle = QSAMPLER_TITLE ": " + tr("Warning");
+		const QString& sText = tr(
+			"About to delete device:\n\n"
 			"%1\n\n"
 			"Are you sure?")
-			.arg(device.deviceName()),
-			QMessageBox::Ok | QMessageBox::Cancel)
-			== QMessageBox::Cancel)
+			.arg(device.deviceName());
+	#if 0
+		if (QMessageBox::warning(this, sTitle, sText,
+			QMessageBox::Ok | QMessageBox::Cancel) == QMessageBox::Cancel)
 			return;
+	#else
+		QMessageBox mbox(this);
+		mbox.setIcon(QMessageBox::Warning);
+		mbox.setWindowTitle(sTitle);
+		mbox.setText(sText);
+		mbox.setStandardButtons(QMessageBox::Ok | QMessageBox::Cancel);
+		QCheckBox cbox(tr("Don't ask this again"));
+		cbox.setChecked(false);
+		cbox.blockSignals(true);
+		mbox.addButton(&cbox, QMessageBox::ActionRole);
+		if (mbox.exec() == QMessageBox::Cancel)
+			return;
+		if (cbox.isChecked())
+			pOptions->bConfirmRemove = false;
+	#endif
 	}
 
 	// Go and destroy...
@@ -453,10 +479,10 @@ void DeviceForm::selectDevice ()
 		QPixmap pixmap;
 		switch (device.deviceType()) {
 		case Device::Audio:
-			pixmap = QPixmap(":/icons/audio2.png");
+			pixmap = QPixmap(":/images/audio2.png");
 			break;
 		case Device::Midi:
-			pixmap = QPixmap(":/icons/midi2.png");
+			pixmap = QPixmap(":/images/midi2.png");
 			break;
 		case Device::None:
 			break;
@@ -614,16 +640,16 @@ void DeviceForm::deviceListViewContextMenu ( const QPoint& pos )
 	bool bClient = (pMainForm->client() != NULL);
 	bool bEnabled = (pItem != NULL);
 	pAction = menu.addAction(
-		QIcon(":/icons/deviceCreate.png"),
+		QIcon(":/images/deviceCreate.png"),
 		tr("&Create device"), this, SLOT(createDevice()));
 	pAction->setEnabled(bEnabled || (bClient && m_bNewDevice));
 	pAction = menu.addAction(
-		QIcon(":/icons/deviceDelete.png"),
+		QIcon(":/images/deviceDelete.png"),
 		tr("&Delete device"), this, SLOT(deleteDevice()));
 	pAction->setEnabled(bEnabled && !m_bNewDevice);
 	menu.addSeparator();
 	pAction = menu.addAction(
-		QIcon(":/icons/formRefresh.png"),
+		QIcon(":/images/formRefresh.png"),
 		tr("&Refresh"), this, SLOT(refreshDevices()));
 	pAction->setEnabled(bClient);
 
