@@ -1,7 +1,7 @@
 // qsamplerInstrumentListForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
    Copyright (C) 2007, Christian Schoenebeck
 
    This program is free software; you can redistribute it and/or
@@ -25,13 +25,13 @@
 
 #include "ui_qsamplerInstrumentListForm.h"
 
-#include "qsamplerInstrumentList.h"
-
+class QModelIndex;
 class QComboBox;
 
-
 namespace QSampler {
 
+class InstrumentListView;
+
 //-------------------------------------------------------------------------
 // QSampler::InstrumentListForm -- Instrument map list form interface.
 //
@@ -42,37 +42,35 @@ class InstrumentListForm : public QMainWindow
 
 public:
 
-	InstrumentListForm(QWidget* pParent = NULL, Qt::WindowFlags wflags = 0);
+	InstrumentListForm(QWidget *pParent = NULL, Qt::WindowFlags wflags = 0);
 	~InstrumentListForm();
 
 public slots:
 
+	void newInstrument();
 	void editInstrument();
 	void editInstrument(const QModelIndex& index);
-	void newInstrument();
 	void deleteInstrument();
 	void refreshInstruments();
 	void activateMap(int);
 
 	void stabilizeForm();
 
-	// Handle custom context menu here...
-	void contextMenu(const QPoint& pos);
-
 protected:
 
 	void showEvent(QShowEvent *);
 	void hideEvent(QHideEvent *);
 	void closeEvent(QCloseEvent *);
 
+	void contextMenuEvent(QContextMenuEvent *);
+
 private:
 
 	Ui::qsamplerInstrumentListForm m_ui;
 
-	MidiInstrumentsModel m_model;
-	MidiInstrumentsDelegate m_delegate;
+	QComboBox *m_pMapComboBox;
 
-	QComboBox* m_pMapComboBox;
+	InstrumentListView *m_pInstrumentListView;
 };
 
 } // namespace QSampler
